ReNomQ version 0.2b1
=====================
ReNomQ is a machine learning framework for quantum machine learning and quantum optimization.

* http://renom.jp/packages/renomq/index.html

Change v0.1b1 => v0.2b1
------------------------------------
* Add Quantum machine learning module.


Requirements
------------
* Linux/Ubuntu
* Python 3.6
* numpy 1.15.4
* matplotlib 3.0.2
* ply 3.11
* networkx 2.2
* Pillow 6.0.0
* sympy 1.3


Installation
------------
First clone the ReNomQ repository.
~~~
git clone https://github.com/ReNom-dev-team/ReNomQ.git
~~~
Then move to the ReNomQ folder, install the module using pip.
~~~
cd ReNomQ
pip install -r requirements.txt
pip install -e .
~~~


License
--------
“ReNomQ” is provided by GRID inc., as subscribed software.  By downloading ReNomQ, you are agreeing to be bound by our ReNom Subscription agreement between you and GRID inc.
To use ReNomQ for commercial purposes, you must first obtain a paid license. Please contact us or one of our resellers.  If you are an individual wishing to use ReNomQ for academic, educational and/or product evaluation purposes, you may use ReNomQ royalty-free.
The ReNom Subscription agreements are subject to change without notice. You agree to be bound by any such revisions. You are responsible for visiting www.renom.jp to determine the latest terms to which you are bound.
